define postfix::dkim::zone(
  $domain = $title,
  $certificate_name = 'mail',

) {

  validate_string($domain)

  file { "/etc/opendkim/${domain}":
    ensure  => directory,
    mode    => '0700',
    require => Class['postfix::dkim'],
  }

  # Certificates
  exec { "${domain}-generate-dkim-certificate":
    command => "opendkim-genkey -r -h rsa-sha256 -d ${domain} -D /etc/opendkim/${domain} -s ${certificate_name} && mv /etc/opendkim/${domain}/${certificate_name}.private /etc/opendkim/${domain}/${certificate_name} && chmod u=rw,go-rwx /etc/opendkim/${domain}/* && chown opendkim:opendkim /etc/opendkim/${domain}/*",
    creates => "/etc/opendkim/${domain}/${certificate_name}",
    path    => ['/usr/bin', '/usr/sbin', '/bin'],
    require => File["/etc/opendkim/${domain}"],
  }

  concat::fragment { "${domain}-keyTable":
    target  => $postfix::dkim::keyTable,
    content => template('postfix/dkim/keyTable.erb'),
    order   => 10,
  }

  concat::fragment { "${domain}-signingTable":
    target  => $postfix::dkim::signingTable,
    content => template('postfix/dkim/signingTable.erb'),
    order   => 10,
  }

  concat::fragment { "${domain}-trustedHost":
    target  => $postfix::dkim::trustedHost,
    content => template('postfix/dkim/trustedHostDomain.erb'),
    order   => 10,
  }
}
